@@ -8,6 +8,7 @@ import signal
 import sys
 import threading
 import time
+import os
 from types import FrameType
 
 import pywintypes
@@ -148,7 +149,7 @@ COMMANDS = {
 
 # --- OverlayManager ---
 class OverlayManager:
-    def __init__(self, pipe_name: str = r"\\.\pipe\overlay_manager"):
+    def __init__(self):
         self.className = "TransparentOverlayWindow"
         self.rectangles = []
         self.countdowns = {}
@@ -158,7 +159,8 @@ class OverlayManager:
         self._next_qrcode_id = 1
         self._qrcode_order = 0
         self._countdown_order = 0
-        self.pipe_name = pipe_name
+        pipe_name = os.environ.get("OVERLAY_PIPE_NAME", "overlay_manager")
+        self.pipe_name = rf"\\.\pipe\{pipe_name}"
         self.shutdown_event = threading.Event()
         self.command_queue = queue.Queue()
         self._break_until = 0.0
